from setuptools import setup

setup(
    name='stibnite',
    version='0.0.0',
    description='Automated python documentation generator ',
    long_description='',
    url='https://github.com/csci-arch/stibnite',
    author='csci-arch',
    author_email='csciarch@gmail.com',
    packages=[],
    classifiers=['Development Status :: 1 - Planning'],
)